==> cdktf-cdktf-provider-google-0.7.6.tar.gz: package/lib/data-google-bigquery-default-service-account.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleBigqueryDefaultServiceAccountConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/bigquery_default_service_account#project DataGoogleBigqueryDefaultServiceAccount#project}
    */
    readonly project?: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/bigquery_default_service_account google_bigquery_default_service_account}
*/
export declare class DataGoogleBigqueryDefaultServiceAccount extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_bigquery_default_service_account";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/bigquery_default_service_account google_bigquery_default_service_account} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleBigqueryDefaultServiceAccountConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleBigqueryDefaultServiceAccountConfig);
    get email(): string;
    get id(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-2.0.15.tar.gz: package/lib/data-google-bigquery-default-service-account.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleBigqueryDefaultServiceAccountConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/bigquery_default_service_account#id DataGoogleBigqueryDefaultServiceAccount#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/bigquery_default_service_account#project DataGoogleBigqueryDefaultServiceAccount#project}
    */
    readonly project?: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/bigquery_default_service_account google_bigquery_default_service_account}
*/
export declare class DataGoogleBigqueryDefaultServiceAccount extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_bigquery_default_service_account";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/bigquery_default_service_account google_bigquery_default_service_account} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleBigqueryDefaultServiceAccountConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleBigqueryDefaultServiceAccountConfig);
    get email(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
